==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/core/l10n/eo.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas.",
    "The selected file is not an image." : "La elektita dosiero ne estas bildo",
    "No image or file provided" : "Neniu bildo aŭ dosiero donis",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
    "Crop is not square" : "Sekco ne estas kvardrata",
    "Password reset is disabled" : "Pasvorto rekomenci malkapablas",
    "%s password reset" : "%s pasvorton rekomenci",
    "Password reset" : "Rekomenci pasvorton",
    "Reset your password" : "Rekomenci vian pasvorton ",
    "[%d / %d]: %s" : "[%d / %d]\\: %s ",
    "[%d / %d]: Checking table %s" : "[%d / %d]\\: kontrole tabelo %s ",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Updated \"%s\" to %s" : "Ĝisdatiĝis “%s” al %s",
    "%s (incompatible)" : "%s (nekongrua)",
    "Following apps have been disabled: %s" : "Jenaj aplikaĵoj malkapablas: %s",
    "Already up to date" : "Jam aktuala",
    "No contacts found" : "Neniu kontakto troviĝis ",
    "Show all contacts …" : "Montri ĉiujn artikolojn kontaktojn",
    "Settings" : "Agordo",
    "Connection to server lost" : "Konekto al servilo perdita",
    "Saving..." : "Konservante...",
    "Authentication required" : "Aŭtentiĝo nepras",
    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas ke vi konfirmas vian pasvorton",
    "Confirm" : "Konfirmi",
    "Password" : "Pasvorto",
    "Failed to authenticate, try again" : "Malsukcesis aŭtentiĝi, provu ree",
    "seconds ago" : "sekundoj antaŭe",
    "Logging in …" : "Ensaluti ...",
    "I know what I'm doing" : "mi scias, kion mi faras",
    "Password can not be changed. Please contact your administrator." : "Pasvorton ne eblas ŝanĝi. Bonvolu kontakti vian administranton.",
    "Reset password" : "Rekomenci la pasvorton",
    "Sending email …" : "Sendante retpoŝton ...",
    "No" : "Ne",
    "Yes" : "Jes",
    "No files in here" : "Neniu dosiero ĉi tie",
    "Choose" : "Elekti",
    "Copy" : "Kopii",
    "Move" : "Movi",
    "Error loading file picker template: {error}" : "eraro ŝarĝi ",
    "OK" : "Akcepti",
    "Error loading message template: {error}" : "Eraris ŝargo de mesaĝa ŝablono: {eraro}",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭri",
    "(all selected)" : "(ĉiuj elektitas)",
    "({count} selected)" : "({count} elektitas)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Pending" : "okazanta",
    "Copy to {folder}" : "Kopii al {folder}",
    "Move to {folder}" : "Movi al {folder}",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Error occurred while checking server setup" : "Eraris kontrolo de servila agordo",
    "Shared" : "Kunhavata",
    "Shared with" : "Kunhavigis kun",
    "Shared by" : "Kunhavigis el",
    "Error setting expiration date" : "Eraro dum agordado de limdato",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii",
    "Press Ctrl-C to copy." : "Premu Ctrl-C pro kopii.",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Share to {name}" : "Kunhavigi al {name}",
    "Share link" : "Kunhavigi ligilon",
    "Link" : "Ligilo",
    "Password protect" : "Protekti per pasvorto",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "group" : "grupo",
    "remote" : "fora",
    "shared by {sharer}" : "kunhavigis de {sharer}",
    "Unshare" : "Malkunhavigi",
    "Can reshare" : "Eblas rekunhavigi",
    "Can change" : "Eblas ŝanĝi",
    "Could not unshare" : "Ne malkunhaveblas",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Share details could not be loaded for this item." : "Kunhavaj detaloj ne ŝargeblis por ĉi tiu ero.",
    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
    "An error occurred (\"{message}\"). Please try again" : "Eraro okazis (\"{message}\"). Bonvolu provi ree.",
    "An error occurred. Please try again" : "Eraro okazis. Bonvolu provi ree",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (remote)" : "{sharee} (fora)",
    "Share" : "Kunhavigi",
    "Name or email address..." : "Nomo aŭ retpoŝtadreso...",
    "Name..." : "Nomo...",
    "Error" : "Eraro",
    "Error removing share" : "Eraris forigo de kunhavigo",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "invisible" : "nevidebla",
    "({scope})" : "({scope})",
    "Delete" : "Forigi",
    "Rename" : "Alinomigi",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "Hello {name}, the weather is {weather}" : "Saluton, {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton, {name}",
    "new" : "nova",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "Searching other places" : "Serĉante en aliaj lokoj",
    "Personal" : "Persona",
    "Users" : "Uzantoj",
    "Apps" : "Aplikaĵoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Access forbidden" : "Aliro estas malpermesata",
    "File not found" : "Dosiero ne troviĝis",
    "Internal Server Error" : "Ena servileraro",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Security warning" : "Sekureca averto",
    "Create an <strong>admin account</strong>" : "Krei <strong>administran konton</strong>",
    "Username" : "Uzantonomo",
    "Storage & database" : "Memoro kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Database host" : "Datumbaza gastigo",
    "SQLite will be used as database." : "SQLite uziĝos kiel datumbazo.",
    "For larger installations we recommend to choose a different database backend." : "Por pli grandaj instaloj ni rekomendas elekti malsaman datumbazomotoron.",
    "Finish setup" : "Fini la instalon",
    "Finishing …" : "Finante...",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "More apps" : "Pli aplikaĵoj",
    "Search" : "Serĉi",
    "Contacts" : "Kontaktoj",
    "Confirm your password" : "Konfirmas vian pasvorton",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "An internal error occurred." : "Ena servileraro okazis.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Username or email" : "Salutnomo aŭ retpoŝtadreso",
    "Log in" : "Ensaluti",
    "Wrong password." : "Malĝusta pasvorto.",
    "App token" : "Apa ĵetono",
    "Grant access" : "Doni alirpermeson",
    "Alternative log in using app token" : "Alia ensaluti per apa ĵetono",
    "New password" : "Nova pasvorto",
    "New Password" : "Nova pasvorto",
    "%s will be updated to version %s" : "%s ĝisdatiĝos al eldono %s",
    "These apps will be updated:" : "Ĉi tiuj aplikaĵoj ĝisdatiĝos:",
    "These incompatible apps will be disabled:" : "Ĉi tiuj malkongruaj aplikaĵoj malkapabliĝos:",
    "Start update" : "Ekĝisdatigi",
    "Update needed" : "Bezonas ĝisdatigi",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumenton</a> por helpo.",
    "Thank you for your patience." : "Dankon pro via pacienco.",
    "Shared with {recipients}" : "Kunhavigis kun {recipients}",
    "This action requires you to confirm your password:" : "Tiu ĉi ago bezonas ke vi konfirmas vian pasvorton:",
    "Wrong password. Reset it?" : "Falsa pasvorto. Ĉu vi volas rekomenci ĝin?",
    "Stay logged in" : "Daŭri ensalutinta",
    "Alternative Logins" : "Alternativaj ensalutoj",
    "Alternative login using app token" : "Alia ensaluti per apa ĵetono",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Vidu la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumenton</a> por helpo."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/core/l10n/eo.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas.",
    "The selected file is not an image." : "La elektita dosiero ne estas bildo",
    "The selected file cannot be read." : "La elektita dosiero ne eblas legi",
    "Invalid file provided" : "Nevalida dosiero donis",
    "No image or file provided" : "Neniu bildo aŭ dosiero donis",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
    "Crop is not square" : "Sekco ne estas kvardrata",
    "Password reset is disabled" : "Pasvorto rekomenci malkapablas",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ne eblas sendi retpoŝton ĉar ne estas retpoŝtadreso por ĉu tiu uzantonomo. Bonvolu kontakti vian administranton.",
    "%s password reset" : "%s pasvorton rekomenci",
    "Password reset" : "Rekomenci pasvorton",
    "Reset your password" : "Rekomenci vian pasvorton ",
    "Couldn't send reset email. Please contact your administrator." : "Ne eblas sendi rekomencan retpoŝton. Bonvolu kontakti vian administranton.",
    "[%d / %d]: %s" : "[%d / %d]\\: %s ",
    "[%d / %d]: Checking table %s" : "[%d / %d]\\: kontrole tabelo %s ",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Checking updates of apps" : "Kontrolas ĝisdatigojn de aplikaĵoj",
    "Updated \"%s\" to %s" : "Ĝisdatiĝis “%s” al %s",
    "Reset log level" : "Rekomenci nivelon de la protokolo",
    "%s (incompatible)" : "%s (nekongrua)",
    "Following apps have been disabled: %s" : "Jenaj aplikaĵoj malkapablas: %s",
    "Already up to date" : "Jam aktuala",
    "Search contacts …" : "Serĉanti kontaktojn …",
    "No contacts found" : "Neniu kontakto troviĝis ",
    "Show all contacts …" : "Montri ĉiujn artikolojn kontaktojn",
    "Could not load your contacts" : "Ne ŝargeblis viajn kontaktojn",
    "Loading your contacts …" : "Ŝargas viajn kontaktojn …",
    "No action available" : "Neniu ago disponebla",
    "Settings" : "Agordo",
    "Connection to server lost" : "Konekto al servilo perdita",
    "Saving..." : "Konservante...",
    "Dismiss" : "Forsendi",
    "Authentication required" : "Aŭtentiĝo nepras",
    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas ke vi konfirmas vian pasvorton",
    "Confirm" : "Konfirmi",
    "Password" : "Pasvorto",
    "Failed to authenticate, try again" : "Malsukcesis aŭtentiĝi, provu ree",
    "seconds ago" : "sekundoj antaŭe",
    "Logging in …" : "Ensaluti ...",
    "I know what I'm doing" : "mi scias, kion mi faras",
    "Password can not be changed. Please contact your administrator." : "Pasvorton ne eblas ŝanĝi. Bonvolu kontakti vian administranton.",
    "Reset password" : "Rekomenci la pasvorton",
    "Sending email …" : "Sendante retpoŝton ...",
    "No" : "Ne",
    "Yes" : "Jes",
    "No files in here" : "Neniu dosiero ĉi tie",
    "Choose" : "Elekti",
    "Copy" : "Kopii",
    "Move" : "Movi",
    "Error loading file picker template: {error}" : "eraro ŝarĝi ",
    "OK" : "Akcepti",
    "Error loading message template: {error}" : "Eraris ŝargo de mesaĝa ŝablono: {eraro}",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭri",
    "(all selected)" : "(ĉiuj elektitas)",
    "({count} selected)" : "({count} elektitas)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Pending" : "okazanta",
    "Copy to {folder}" : "Kopii al {folder}",
    "Move to {folder}" : "Movi al {folder}",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Error occurred while checking server setup" : "Eraris kontrolo de servila agordo",
    "Shared" : "Kunhavata",
    "Shared with" : "Kunhavigis kun",
    "Shared by" : "Kunhavigis el",
    "Error setting expiration date" : "Eraro dum agordado de limdato",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Copied!" : "Kopiinta!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii",
    "Press Ctrl-C to copy." : "Premu Ctrl-C pro kopii.",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Share to {name}" : "Kunhavigi al {name}",
    "Share link" : "Kunhavigi ligilon",
    "Link" : "Ligilo",
    "Password protect" : "Protekti per pasvorto",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "Allow upload and editing" : "Permesi alŝuton kaj redakton",
    "Read only" : "Nurlega",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "group" : "grupo",
    "remote" : "fora",
    "email" : "retpoŝto",
    "shared by {sharer}" : "kunhavigis de {sharer}",
    "Unshare" : "Malkunhavigi",
    "Can reshare" : "Eblas rekunhavigi",
    "Can edit" : "Povas redakti",
    "Can create" : "Povas krei",
    "Can change" : "Eblas ŝanĝi",
    "Can delete" : "Povas forigi",
    "Access control" : "Alirkontrolo",
    "Could not unshare" : "Ne malkunhaveblas",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Share details could not be loaded for this item." : "Kunhavaj detaloj ne ŝargeblis por ĉi tiu ero.",
    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
    "An error occurred (\"{message}\"). Please try again" : "Eraro okazis (\"{message}\"). Bonvolu provi ree.",
    "An error occurred. Please try again" : "Eraro okazis. Bonvolu provi ree",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (remote)" : "{sharee} (fora)",
    "{sharee} (email)" : "{sharee} (email)",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Kunhavigi",
    "Name or email address..." : "Nomo aŭ retpoŝtadreso...",
    "Name or federated cloud ID..." : "Namo aŭ federnuba identigilo...",
    "Name, federated cloud ID or email address..." : "Nomo, federnuba identigilo aŭ retpoŝtadreso...",
    "Name..." : "Nomo...",
    "Error" : "Eraro",
    "Error removing share" : "Eraris forigo de kunhavigo",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "invisible" : "nevidebla",
    "({scope})" : "({scope})",
    "Delete" : "Forigi",
    "Rename" : "Alinomigi",
    "No tags found" : "Neniu etikedo troviĝis ",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "Hello {name}, the weather is {weather}" : "Saluton, {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton, {name}",
    "new" : "nova",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "Update to {version}" : "Ĝisdatigi al {version}",
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "Continue to Nextcloud" : "Daŭri al Nextcloud",
    "Searching other places" : "Serĉante en aliaj lokoj",
    "Personal" : "Persona",
    "Users" : "Uzantoj",
    "Apps" : "Aplikaĵoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Access forbidden" : "Aliro estas malpermesata",
    "File not found" : "Dosiero ne troviĝis",
    "Internal Server Error" : "Ena servileraro",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Trace" : "Paŭsi",
    "Security warning" : "Sekureca averto",
    "Create an <strong>admin account</strong>" : "Krei <strong>administran konton</strong>",
    "Username" : "Uzantonomo",
    "Storage & database" : "Memoro kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "For more details check out the documentation." : "Por pli detaloj vidu la dokumentaron.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Database host" : "Datumbaza gastigo",
    "Performance warning" : "Rendimenta averto",
    "SQLite will be used as database." : "SQLite uziĝos kiel datumbazo.",
    "For larger installations we recommend to choose a different database backend." : "Por pli grandaj instaloj ni rekomendas elekti malsaman datumbazomotoron.",
    "Finish setup" : "Fini la instalon",
    "Finishing …" : "Finante...",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "More apps" : "Pli aplikaĵoj",
    "More apps menu" : "Menuo de pli aplikaĵoj",
    "Search" : "Serĉi",
    "Contacts" : "Kontaktoj",
    "Contacts menu" : "Menuo de kontakto",
    "Settings menu" : "Menuo de agordo",
    "Confirm your password" : "Konfirmas vian pasvorton",
    "Server side authentication failed!" : "Servilo flanka aŭtentigo malsukcesis!",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "An internal error occurred." : "Ena servileraro okazis.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Username or email" : "Salutnomo aŭ retpoŝtadreso",
    "Log in" : "Ensaluti",
    "Wrong password." : "Malĝusta pasvorto.",
    "App token" : "Apa ĵetono",
    "Grant access" : "Doni alirpermeson",
    "Alternative log in using app token" : "Alia ensaluti per apa ĵetono",
    "New password" : "Nova pasvorto",
    "New Password" : "Nova pasvorto",
    "Two-factor authentication" : "du factora aŭtentiĝo",
    "Cancel log in" : "Nuligi ensaluto",
    "Use backup code" : "Uzi rezervan kodon",
    "App update required" : "Aplikaĵon ĝisdatigi nepras",
    "%s will be updated to version %s" : "%s ĝisdatiĝos al eldono %s",
    "These apps will be updated:" : "Ĉi tiuj aplikaĵoj ĝisdatiĝos:",
    "These incompatible apps will be disabled:" : "Ĉi tiuj malkongruaj aplikaĵoj malkapabliĝos:",
    "Start update" : "Ekĝisdatigi",
    "Detailed logs" : "Detalaj protokoloj",
    "Update needed" : "Bezonas ĝisdatigi",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumenton</a> por helpo.",
    "Thank you for your patience." : "Dankon pro via pacienco.",
    "Shared with {recipients}" : "Kunhavigis kun {recipients}",
    "This action requires you to confirm your password:" : "Tiu ĉi ago bezonas ke vi konfirmas vian pasvorton:",
    "Wrong password. Reset it?" : "Falsa pasvorto. Ĉu vi volas rekomenci ĝin?",
    "Stay logged in" : "Daŭri ensalutinta",
    "Alternative Logins" : "Alternativaj ensalutoj",
    "Alternative login using app token" : "Alia ensaluti per apa ĵetono",
    "Add \"%s\" as trusted domain" : "Aldoni \"%s\" tiel fida retregiono",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Vidu la <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">dokumenton</a> por helpo.",
    "Back to log in" : "Revenu al ensaluto"
},
"nplurals=2; plural=(n != 1);");
